package sun.net.idn;

import java.io.IOException;
import java.io.InputStream;
import java.io.DataInputStream;
import sun.text.normalizer.ICUBinary;

final class StringPrepDataReader implements ICUBinary.Authenticate
{
    private DataInputStream dataInputStream;
    private byte[] unicodeVersion;
    private static final byte[] DATA_FORMAT_ID;
    private static final byte[] DATA_FORMAT_VERSION;
    
    public StringPrepDataReader(InputStream in) throws IOException {
        this.unicodeVersion = ICUBinary.readHeader(in, StringPrepDataReader.DATA_FORMAT_ID, this);
        this.dataInputStream = new DataInputStream(in);
    }
    
    public void read(byte[] b, char[] array) throws IOException {
        this.dataInputStream.read(b);
        for (int i = 0; i < array.length; ++i) {
            array[i] = this.dataInputStream.readChar();
        }
    }
    
    public byte[] getDataFormatVersion() {
        return StringPrepDataReader.DATA_FORMAT_VERSION;
    }
    
    public boolean isDataVersionAcceptable(byte[] array) {
        return array[0] == StringPrepDataReader.DATA_FORMAT_VERSION[0] && array[2] == StringPrepDataReader.DATA_FORMAT_VERSION[2] && array[3] == StringPrepDataReader.DATA_FORMAT_VERSION[3];
    }
    
    public int[] readIndexes(int n) throws IOException {
        int[] array = new int[n];
        for (int i = 0; i < n; ++i) {
            array[i] = this.dataInputStream.readInt();
        }
        return array;
    }
    
    public byte[] getUnicodeVersion() {
        return this.unicodeVersion;
    }
    
    static {
        DATA_FORMAT_ID = new byte[] { 83, 80, 82, 80 };
        DATA_FORMAT_VERSION = new byte[] { 3, 2, 5, 2 };
    }
}
